@@ -46,7 +46,6 @@ class Menus(RanaModule):
         self.listOffset = 0
         self.setupGeneralMenus()
         self.lastActivity = int(time.time())
-        self.fullscreen = False
         self.mainScreenCoords = {}
         self.userConfig = self.modrana.configs.getUserConfig()
         self.hideMapScreenButtons = False
@@ -170,13 +169,13 @@ class Menus(RanaModule):
 
 
             # draw the maximize icon
-            if self.fullscreen:
+            if self.modrana.gui.fullscreen:
                 icon = 'center:minimize;0.05'
             else:
                 icon = 'center:maximize;0.05'
 
             (x1, y1) = buttons['fullscreen']
-            self.drawButton(cr, x1, y1, dx, dy, "", icon, "ms:display:fullscreen:toggle")
+            self.drawButton(cr, x1, y1, dx, dy, "", icon, "ms:gui:fullscreen:toggle")
 
             # draw the centering button
             (x1, y1) = buttons['centre']
@@ -335,7 +334,7 @@ class Menus(RanaModule):
                 m.registerXYWH(x1, y1, w, h, action, timedAction)
 
     def resetMenu(self, menu=None):
-        print("Menu knows menu changed")
+        self.log.debug("Menu knows menu changed")
         self.listOffset = 0
 
     def dragEvent(self, startX, startY, dx, dy, x, y):
@@ -345,7 +344,7 @@ class Menus(RanaModule):
         menuList = self.lists.get(menuName, None)
         if menuList is not None:
             self.listOffset += dy
-            print("Drag in menu + %f = %f" % (dy, self.listOffset))
+            self.log.debug("Drag in menu + %f = %f", dy, self.listOffset)
 
     def setItemMenuGrid(self, x1, y1, cols, rows, dx, dy):
         """generate an icon placement grid for a given number of
@@ -378,14 +377,14 @@ class Menus(RanaModule):
             if module:
                 module.drawMenu(cr, menuName)
             else:
-                print('menu: module %s that should handle menu drawing is missing' % moduleName)
+                self.log.error('module %s that should handle menu drawing is missing', moduleName)
         elif len(split) == 3:
             (moduleName, menuName, args) = split
             module = self.m.get(moduleName, None)
             if module:
                 module.drawMenu(cr, menuName, args)
             else:
-                print('menu: module %s that should handle menu drawing is missing' % moduleName)
+                self.log.error('module %s that should handle menu drawing is missing', moduleName)
 
     def drawMenu(self, cr, menuName, args=None):
         """Handles list menus"""
@@ -398,7 +397,7 @@ class Menus(RanaModule):
                 index = None
 
             if listName in self.lists.keys():
-            #        print("drawing list: %s" % menuName)
+            #        self.log.debug("drawing list: %s" % menuName)
                 self.lists[listName].draw(cr, index) # draw the list
         elif menuName == 'listDetail':
             listName, index = args.split('#', 1)
@@ -415,7 +414,7 @@ class Menus(RanaModule):
         # Find the menu
         menu = self.menus.get(menuName, None)
         if menu is None:
-            print("Menu %s doesn't exist, returning to main screen" % menuName)
+            self.log.error("Menu %s doesn't exist, returning to main screen", menuName)
             self.set('menu', None)
             self.set('needRedraw', True)
             return
@@ -426,7 +425,7 @@ class Menus(RanaModule):
         """Draw the item menu"""
         vp = self.get('viewport', None)
         if not vp:
-            print('menu: ERROR, no viewport found')
+            self.log.error('ERROR, no viewport found')
             return
         else:
             (x1, y1, w, h) = vp
@@ -554,7 +553,7 @@ class Menus(RanaModule):
         if itemType == 'list':
             self.lists[menu] = module
         else:
-            print("Can't register \"%s\" menu - unknown type" % itemType)
+            self.log.error("Can't register \"%s\" menu - unknown type", itemType)
 
     def initMenu(self, menu):
         """initialize menu a menu dictionary instance to default parameters"""
@@ -686,7 +685,7 @@ class Menus(RanaModule):
 
         self.drawThreePlusOneMenu(cr, 'pointDetail', backAction, button1, button2, box, wrap=True)
 
-    def drawPointToolsMenu(self, cr, point, backAction):
+    def drawPointToolsMenu(self, cr, point, group, backAction):
         """draw a detailed menu for a Point object"""
 
         # check if the for this point is cached
@@ -700,10 +699,11 @@ class Menus(RanaModule):
             gi = self.generateItem # for better readability
             # clear old route and route to the point
             routing = 'route:clearRoute|md:route:route:type=pos2ll;toLat=%f;toLon=%f;show=start' % (lat, lon)
+            clearAll = 'ms:markers:removeGroup:%s|set:menu:None' % group.name
             items = [
                 gi('here#route', 'generic', routing),
-                gi('to POI#add', 'generic', 'ms:menu:handleToolsMenuPoint:store'), # TODO implement this
-                gi('results#clear all', 'generic', 'set:menu:None') # TODO implement this
+                gi('to POI#add', 'generic', 'ms:menu:handleToolsMenuPoint:store'),
+                gi('results#clear', 'generic', clearAll)
             ]
             # add the items to a menu
             menu = self.addItemsToThisMenu(menu, items)
@@ -812,7 +812,7 @@ class Menus(RanaModule):
 
         def drawItemToolsMenu(self, cr, index):
             item = self.container.getItem(index)
-            self.drawItemToolsMenuFunction(cr, item, self._getBackToListDetailAction(index))
+            self.drawItemToolsMenuFunction(cr, item, self, self._getBackToListDetailAction(index))
 
         def _getBackToListAction(self, index):
             return "ml:menu:setListIndex:%s;%d|set:menu:menu#list#%s" % (self.name, index, self.name)
@@ -897,7 +897,7 @@ class Menus(RanaModule):
             if 0 <= index < self.container.getLength():
                 self.index = index
             else:
-                print("listable menu %s: invalid index: %d" % (self.getName(), index))
+                self.log.error("listable menu %s: invalid index: %d", self.getName(), index)
 
         def setOnceBackAction(self, action):
             """replace the back button action with a given action for a single listable menu entry"""
@@ -943,7 +943,23 @@ class Menus(RanaModule):
         self.clearMenu('searchWhere')
         self.addItem('searchWhere', 'view#near', 'generic', 'ms:search:setWhere:view|set:menu:search')
         self.addItem('searchWhere', 'position#near', 'generic', 'ms:search:setWhere:position|set:menu:search')
-        # TODO:
+        # local search radius toggle button
+        #TODO: make this more sane
+        textIconAction = [
+            ("500 m#radius", "", "set:localSearchRadius:500"),
+            ("1 km#radius", "", "set:localSearchRadius:1000"),
+            ("5 km#radius", "", "set:localSearchRadius:5000"),
+            ("10 km#radius", "", "set:localSearchRadius:10000"),
+            ("25 km#radius", "", "set:localSearchRadius:25000"),
+            ("50 km#radius", "", "set:localSearchRadius:50000")
+        ]
+
+        radiusList = [500, 1000, 5000, 10000, 25000, 50000]
+        #lastValue = int(self.get('localSearchRadius', 0))
+        index = self.get('localSearchRadiusToggleButton', 3)
+        self.addToggleItem('searchWhere', textIconAction,
+                           index, None, 'localSearchRadiusToggleButton')
+
         # * near tracklog
         #  * start
         #  * end
@@ -956,7 +972,7 @@ class Menus(RanaModule):
         self.addItem('searchWhat', 'online#address', 'generic', 'search:searchAddress')
         self.addItem('searchWhat', 'online#wikipedia', 'generic', 'search:searchWikipedia')
         self.addItem('searchWhat', 'online#presets', 'generic', 'set:menu:searchWhere')
-        self.addItem('searchWhat', 'results#clear', 'generic', 'search:clearSearch|set:menu:None')
+        self.addItem('searchWhat', 'results#clear all', 'generic', 'search:clearSearch|set:menu:None')
 
     def setupSearchMenus(self):
         """Create a load of menus that are just filters for OSM tags"""
@@ -1143,7 +1159,7 @@ class Menus(RanaModule):
 
     def setupInfoMenu(self):
         self.clearMenu('info')
-        self.addItem('info', 'to point#Direction', 'generic', 'set:menu:info#infoDirection')
+        #self.addItem('info', 'to point#Direction', 'generic', 'set:menu:info#infoDirection')
         self.addItem('info', 'About', 'generic', 'set:menu:info#infoAbout')
 
     def setupAboutMenu(self):
@@ -1488,13 +1504,9 @@ class Menus(RanaModule):
                 if l:
                     l.setIndex(int(args[1]))
                 else:
-                    print("menu: no list %s available, can't set index" % listName)
+                    self.log.error("no list %s available, can't set index", listName)
             except Exception:
-                import sys
-
-                e = sys.exc_info()[1]
-                print("menu: setting list index failed")
-                print(e)
+                self.log.exception("setting list index failed")
 
         elif messageType == "ms" and message == "openUrl":
             url = args
@@ -1526,7 +1538,7 @@ class Menus(RanaModule):
                 if point and store:
                     store.storePoint(point, returnToMenu=None)
                 else:
-                    print("menu: can't store point, point or storePOI module missing")
+                    self.log.error("can't store point, point or storePOI module missing")
 
         elif message == 'askQuit':
             ask = self.m.get('askMenu', None)
